@ Estimates subjects' types using Information Search compliance data    @
@ Note estimations disregard any type with more than eight games with   @
@ zero compliance level with a type's information search requirements   @

clear all;

@ MODULE 1 - Computes log-likelihoods of subjects' information searches @
@ conditional on type and using information search compliance according @
@ to look-up style (early and late)                                     @
@ For every subject returns the best look-up style according to type,   @
@ the best type according to look-up style, the overall best type, and  @
@ the corresponding vector of parameter estimates.                      @
@ Note estimations disregard any type with more than eight games with   @
@ zero compliance level with a type's information search requirements   @


@ Number of Subjects @
@ 71 Baseline Subjects, 17 Open Boxes Subjects are disregarded @
pl= 71;
load A[88,17]=c:\GG_AER_2006\SubjectsGuesses.xls;

@ Loads data on each subject's number of games whose information search @
@ falls into each compliance category according to type                 @
@ One file for each look-up style                                       @
load B[pl*7,9]=c:\GG_AER_2006\DATISEEQ.jnk;
load C[pl*7,9]=c:\GG_AER_2006\DATISLEQ.jnk;

@ Loads data on subjects' information search compliance densities @
@ conditional on type and sorted according to game                @   
@ One file for each look-up style                                 @
load D[16*7,pl]=c:\GG_AER_2006\ANADHB0EQ.jnk;
load E[16*7,pl]=c:\GG_AER_2006\ANADHB0TEQ.jnk;


@ Number of Games @
ga=16;

@ MODULE 1: SETUP @

@ Number of games with greater than zero compliance levels with the @
@ information search requirements of a given type for the early and @
@ late look-up styles                                               @
ngewz=zeros(pl,8);
nglwz=zeros(pl,8);

@ Subjects' log-likelihood estimates according to type for the "early" @
@ (ltote) and "late" (ltotl) look-up styles                            @
@ Column 1 is Sub ID, columns 2 to 8 are log-likelihood estimates      @
ltotewz=ones(pl,8)*(-99);
ltotlwz=ones(pl,8)*(-99);

@ Parameter estimates according to type for the "early" (pvewz) and @
@ "late" (pvlwz) look-up styles                                     @
@ Column 1 is Sub, columns 2 to 4 are the 3 parameter estimates     @
pvewz=zeros(7*pl,4);
pvlwz=zeros(7*pl,4);

@ Parameter estimates for best type conditional on "early" look-up  @
@ style, and conditional on "late" look-up style                    @
@ Column 1 is Sub ID, column 2 identifies best type (1 to 7) given  @
@ "early" look-up style, colums 3 to 5 parameter estimates, column  @
@ 6 identifies best type (1 to 7) given "late" look-up style,       @
@ columns 7 to 9 parameter estimates                                @
pvbeblwz=zeros(pl,9);

@ Subjects' estimated log-likelihoods of best type for the 'early'  @
@ and 'late' look-up styles                                         @
@ Column 1 is Sub ID, column 2 is log-liklelihood estimate of best  @
@ 'early' look-up style type, column 3 identifies that type, column @
@ 4 is log-liklelihood estimate of best 'late' look-up style type,  @
@ column 5 identifies that type, columns 6 to 8 identifies other    @
@ 'early' look-up style types with equal estimated log-likelihood,  @
@ columns 9 to 12 identifies other 'late' look-up style types with  @
@ equal estimated log-likelihood                                    @
beblwz=zeros(pl,12);
beblwz[.,2]=-100000+beblwz[.,2];
beblwz[.,4]=-100000+beblwz[.,4];

@ Subjects' estimated log-likelihoods of best type across look-up   @
@ styles                                                            @
@ Column 1 is Sub ID, column 2 is estimated log-likelihood, column  @
@ 3 identifies best type  (types for "early" look-up style are      @
@ numbered 1 to 7 ,types for "late" look-up style are numbered 8    @
@ to 14), columns 4 to 13 identifies other types with estimated     @
@ log-likelihood equal to best type one (above numbering is used)   @
bloiswz=zeros(pl,13);

@ Parameter estimates of best type across look-up styles            @ 
@ Column 1 is Sub ID, columns 2 to 4 parameter estimates for best   @
@ type, columns 5 to 7, and 8 tp 10 are parameter estimates for up  @
@ to two of the types with estimated log-likelihood of best type    @
pvbtiswz=zeros(pl,10);

@ Parameter estimates of "early" look-up style types with estimated @
@ log-likelihoods equal to best "early" look-up style type and of   @
@ "late" look-up style types with estimated log-likelihoods equal   @
@ to best "early" look-up style                                     @ 
@ Column 1 is Sub ID, columns 2 to 10 sets of parameter estimates   @
@ for additional best "early" look-up style types, columns 11 to 19 @
@ sets of parameter estimates for additional best "late" look-up    @
@ style types                                                       @
tpvbeblwz=zeros(pl,19);

@ Number of games with zero compliance for the best estimated type  @
@ Column 1 is Sub ID, column 2 is number of games with zero         @
@ compliance of the best estimated type, column 3 indicator (1)     @
@ that parameter estimates are equal to {0 0 1}, (2, otherwise)     @ 
btzcwz=zeros(pl,3);



@ END OF MODULE 1 SETUP @


@ MODULE 1 @

s=1;
do while s<=pl;

ty=1;
do while ty<=7;
nzes=0;
nzls=0;

ltotewz[s,1]=A[s,1];
ltotlwz[s,1]=A[s,1];
ngewz[s,1]=A[s,1]*10000;
nglwz[s,1]=A[s,1]*10000;
pvewz[((ty-1)*pl+s),1]=A[s,1];
pvlwz[((ty-1)*pl+s),1]=A[s,1];
beblwz[s,1]=A[s,1]*100;
pvbeblwz[s,1]=A[s,1]*100;
bloiswz[s,1]=A[s,1]*100;
pvbtiswz[s,1]=A[s,1];


@ Counting number of games with zero compliance with a type's information @
@ search requirements according to the "early" and "late" look-up styles  @                       

g=1;
do while g<=16;
   if D[((ty-1)*16+g),s]==0; nzes=nzes+1; endif;
   if E[((ty-1)*16+g),s]==0; nzls=nzls+1; endif;
g=g+1;
endo;

ngewz[s,(1+ty)]=nzes;
nglwz[s,(1+ty)]=nzls;

@ Information Search: computes log-likelihood and identifies the best type @

if nzes < 8;

if B[((ty-1)*pl+s),7]/=0;
 if B[((ty-1)*pl+s),8]/=0;
  if B[((ty-1)*pl+s),9]/=0;
    ltotewz[s,(1+ty)]=(B[((ty-1)*pl+s),7])*ln(B[((ty-1)*pl+s),7]/ga)+
    (B[((ty-1)*pl+s),8])*ln(B[((ty-1)*pl+s),8]/ga)+(B[((ty-1)*pl+s),9])*ln(B[((ty-1)*pl+s),9]/ga);
  elseif B[((ty-1)*pl+s),9]==0;
    ltotewz[s,(1+ty)]=(B[((ty-1)*pl+s),7])*ln(B[((ty-1)*pl+s),7]/ga)+
    (B[((ty-1)*pl+s),8])*ln(B[((ty-1)*pl+s),8]/ga); 
  endif;
 elseif B[((ty-1)*pl+s),8]==0;
  if B[((ty-1)*pl+s),9]/=0;
    ltotewz[s,(1+ty)]=(B[((ty-1)*pl+s),7])*ln(B[((ty-1)*pl+s),7]/ga)+
       (B[((ty-1)*pl+s),9])*ln(B[((ty-1)*pl+s),9]/ga);
  elseif B[((ty-1)*pl+s),9]==0;
    ltotewz[s,(1+ty)]=(B[((ty-1)*pl+s),7])*ln(B[((ty-1)*pl+s),7]/ga);
  endif;  
 endif;
elseif B[((ty-1)*pl+s),7]==0;
  if B[((ty-1)*pl+s),8]/=0;
   if B[((ty-1)*pl+s),9]/=0;
    ltotewz[s,(1+ty)]=(B[((ty-1)*pl+s),8])*ln(B[((ty-1)*pl+s),8]/ga)+
       (B[((ty-1)*pl+s),9])*ln(B[((ty-1)*pl+s),9]/ga);
   elseif B[((ty-1)*pl+s),9]==0;
    ltotewz[s,(1+ty)]=(B[((ty-1)*pl+s),8])*ln(B[((ty-1)*pl+s),8]/ga);
   endif;
  elseif B[((ty-1)*pl+s),8]==0;
    ltotewz[s,(1+ty)]=(B[((ty-1)*pl+s),9])*ln(B[((ty-1)*pl+s),9]/ga);
  endif;
endif;

pvewz[((ty-1)*pl+s),2]=(B[((ty-1)*pl+s),7]/16); 
pvewz[((ty-1)*pl+s),3]=(B[((ty-1)*pl+s),8]/16);
pvewz[((ty-1)*pl+s),4]=(B[((ty-1)*pl+s),9]/16);


endif;

if nzls < 8;

if C[((ty-1)*pl+s),7]/=0;
 if C[((ty-1)*pl+s),8]/=0;
  if C[((ty-1)*pl+s),9]/=0;
    ltotlwz[s,(1+ty)]=(C[((ty-1)*pl+s),7])*ln(C[((ty-1)*pl+s),7]/ga)+
      (C[((ty-1)*pl+s),8])*ln(C[((ty-1)*pl+s),8]/ga)+(C[((ty-1)*pl+s),9])*ln(C[((ty-1)*pl+s),9]/ga);
  elseif C[((ty-1)*pl+s),9]==0;
    ltotlwz[s,(1+ty)]=(C[((ty-1)*pl+s),7])*ln(C[((ty-1)*pl+s),7]/ga)+ 
       (C[((ty-1)*pl+s),8])*ln(C[((ty-1)*pl+s),8]/ga);
  endif;
 elseif C[((ty-1)*pl+s),8]==0;
  if C[((ty-1)*pl+s),9]/=0;
    ltotlwz[s,(1+ty)]=(C[((ty-1)*pl+s),7])*ln(C[((ty-1)*pl+s),7]/ga)+
      (C[((ty-1)*pl+s),9])*ln(C[((ty-1)*pl+s),9]/ga);
  elseif C[((ty-1)*pl+s),9]==0;
    ltotlwz[s,(1+ty)]=(C[((ty-1)*pl+s),7])*ln(C[((ty-1)*pl+s),7]/ga);
  endif;
 endif;
elseif C[((ty-1)*pl+s),7]==0;
  if C[((ty-1)*pl+s),8]/=0;
   if C[((ty-1)*pl+s),9]/=0;
    ltotlwz[s,(1+ty)]=(C[((ty-1)*pl+s),8])*ln(C[((ty-1)*pl+s),8]/ga)+
      (C[((ty-1)*pl+s),9])*ln(C[((ty-1)*pl+s),9]/ga);
   elseif C[((ty-1)*pl+s),9]==0;
    ltotlwz[s,(1+ty)]=(C[((ty-1)*pl+s),8])*ln(C[((ty-1)*pl+s),8]/ga);
   endif;
  elseif C[((ty-1)*pl+s),8]==0;
    ltotlwz[s,(1+ty)]=(C[((ty-1)*pl+s),9])*ln(C[((ty-1)*pl+s),9]/ga);
  endif;
endif;

pvlwz[((ty-1)*pl+s),2]=(C[((ty-1)*pl+s),7]/16); 
pvlwz[((ty-1)*pl+s),3]=(C[((ty-1)*pl+s),8]/16);
pvlwz[((ty-1)*pl+s),4]=(C[((ty-1)*pl+s),9]/16);


endif;

if ltotewz[s,(1+ty)]>beblwz[s,2];
  beblwz[s,2]=ltotewz[s,(1+ty)];
  beblwz[s,3]=ty;
  pvbeblwz[s,2]=ty;
  pvbeblwz[s,3:5]=pvewz[((ty-1)*pl+s),2:4];
endif;
if ltotlwz[s,(1+ty)]>beblwz[s,4];
  beblwz[s,4]=ltotlwz[s,(1+ty)]; 
  beblwz[s,5]=ty;
  pvbeblwz[s,6]=ty;
  pvbeblwz[s,7:9]=pvlwz[((ty-1)*pl+s),2:4];
endif;

ty=ty+1;
endo;

@ Identifies other types with estimated log-likelihoods equal to the best found above @
te=1; tl=1;
ty=1;
do while ty <=7;
 if ltotewz[s,(1+ty)]/=-99;
 if ltotewz[s,(1+ty)]==beblwz[s,2];
   if ty/=beblwz[s,3];                 
     beblwz[s,(4+te)]=ty;
       if te < 4;
        tpvbeblwz[s,(3*(te-1)+2):(3*(te-1)+4)]=pvewz[((ty-1)*pl+s),2:4];
       endif;
     te=te+1;
   endif;
 endif;  
 endif;
 if ltotlwz[s,(1+ty)]/=-99;
 if ltotlwz[s,(1+ty)]==beblwz[s,4];
   if ty/=beblwz[s,5];                   
     beblwz[s,(9+tl)]=ty;
       if tl < 4;
        tpvbeblwz[s,(3*(tl-1)+11):(3*(tl-1)+13)]=pvlwz[((ty-1)*pl+s),2:4];
       endif;
     tl=tl+1;
   endif;
 endif;
 endif;
ty=ty+1;
endo;

@ Identifies overall best type and its corresponding parameter estimates @   
if beblwz[s,2]>beblwz[s,4];
 bloiswz[s,2]=beblwz[s,2];
 bloiswz[s,3]=beblwz[s,3];
 pvbtiswz[s,2:4]=pvewz[((bloiswz[s,3]-1)*pl+s),2:4];
 h=4;
 ty=1;
 do while ty <=7;
  if ty/=bloiswz[s,3];
   if bloiswz[s,2]==ltotewz[s,(1+ty)];
      bloiswz[s,h]=ty;
      if h==4;
       pvbtiswz[s,5:7]=pvewz[((bloiswz[s,h]-1)*pl+s),2:4];
      elseif h==5;
       pvbtiswz[s,8:10]=pvewz[((bloiswz[s,h]-1)*pl+s),2:4];      
      endif;
      h=h+1;
   endif; 
  endif; 
 ty=ty+1;
 endo;
elseif beblwz[s,2]<beblwz[s,4];
 bloiswz[s,2]=beblwz[s,4];
 bloiswz[s,3]=(7+beblwz[s,5]);
 pvbtiswz[s,2:4]=pvlwz[((bloiswz[s,3]-1-7)*pl+s),2:4]; 
 h=4;
 ty=1;
 do while ty <=7;
  if ty/=(bloiswz[s,3]-7);
   if bloiswz[s,2]==ltotlwz[s,(1+ty)];
      bloiswz[s,h]=(ty+7);
      if h==4;
       pvbtiswz[s,5:7]=pvlwz[((bloiswz[s,h]-1-7)*pl+s),2:4];
      elseif h==5;
       pvbtiswz[s,8:10]=pvlwz[((bloiswz[s,h]-1-7)*pl+s),2:4];
      endif;
      h=h+1;
   endif;
  endif; 
 ty=ty+1;
 endo;
elseif beblwz[s,2]==beblwz[s,4];
 if beblwz[s,2]/=-99;
  bloiswz[s,2]=beblwz[s,2];
  bloiswz[s,3]=beblwz[s,3];
  bloiswz[s,4]=(7+beblwz[s,5]);
  pvbtiswz[s,2:4]=pvewz[((bloiswz[s,3]-1)*pl+s),2:4];
  pvbtiswz[s,5:7]=pvlwz[((bloiswz[s,4]-1-7)*pl+s),2:4]; 
  h=5;
  ty=1;
  do while ty <=7;
    if ty/=bloiswz[s,3];
      if bloiswz[s,2]==ltotewz[s,(1+ty)];
          bloiswz[s,h]=ty; if h>6; h;; s; endif;
        if h==5;
         pvbtiswz[s,8:10]=pvewz[((bloiswz[s,h]-1)*pl+s),2:4]; 
        endif;
        h=h+1;
       endif;  
    endif;  
    if ty/=(bloiswz[s,4]-7);
      if bloiswz[s,2]==ltotlwz[s,(1+ty)];       
         bloiswz[s,h]=(ty+7);                     
        if h==5;
          pvbtiswz[s,8:10]=pvlwz[((bloiswz[s,h]-1-7)*pl+s),2:4]; 
        endif;      
        h=h+1;
      endif; 
    endif; 
  ty=ty+1;
  endo;
 endif;
 
endif;

@ Counts number of games with zero compliance with the estimated type's @
@ information each requirements. (This number is equal or less than 8   @
@ becase types with more than eight games with zero compliance are      @
@ ruled out a priori)                                                   @

  btzcwz[s,1]=A[s,1]*100; 
if pvbtiswz[s,4]/=1;
 btzcwz[s,3]=2;
 ind=bloiswz[s,3];   
 if ind/=0; @ Excludes subjects for whom there are no types with no more @
            @ than 8 games with compliance greater than zero             @
   if bloiswz[s,3] < 8;
    g=1;
    do while g<=16;                               
      if D[((ind-1)*16+g),s]==0; btzcwz[s,2]=btzcwz[s,2]+1; endif;
    g=g+1;
    endo;
   elseif bloiswz[s,3] >= 8;
    g=1;
    do while g<=16;
      if E[((ind-7-1)*16+g),s]==0; btzcwz[s,2]=btzcwz[s,2]+1; endif;
    g=g+1;
    endo;
   endif; 
 endif;
endif;


s=s+1;
endo;


output file=c:\GG_AER_2006\Estimatedloglikelihoods_early_search_alltypes.jnk reset;
ltotewz;
output off;

output file=c:\GG_AER_2006\Estimatedloglikelihoods_late_search_alltypes.jnk reset;
ltotlwz;
output off;

output file=c:\GG_AER_2006\TypeEstimResultsAGGDISOSuNOM.jnk reset;

format /m1/rd 6,0;
"Number of games with zero compliance according to the 'early' look-up style";
"for the 7 types considered";
ngewz;
print;
"Number of games with zero compliance according to the 'late' look-up style";
"for the 7 types considered";
nglwz;
print;

format /m1/rd 6,4;
"Subjects' estimated log-likelihood of 'early' look-up style data for";
"the 7 types considered";
ltotewz;
print;
"Subjects' estimated log-likelihood of 'late' look-up style data for";
"the 7 types considered";
ltotlwz;
print;

format /m1/rd 6,3;
"Parameter estimates of best type according to the 'early' and 'late' ";
"look up styles"; 
"Column 1 is Subj ID#, column 2 indicates best 'early' look-up type";
"columns 3 to 5 are the corresponding parameter estimates, column 6";
"indicates best 'late' look-up type, columns 7 to 9 are the corresponding";
"parameter estimates";
pvbeblwz;
print;

"Subjects' estimated types according to the 'early' and 'late' look-up styles";
"Column 1 is Subj ID#, columns 2 and 3 estimated log-likelihood and type for";
"'early' look-up style, columns 4 and 5 estimated log-likelihood and type for";
"'late' look-up style, columns 6 to 8 other 'early' look up style types with";
"equal estimated log-likelihood, columns 9 to 12 other 'late' look up style";
"types with equal estimated log-likelihood,";
beblwz;
print;

format /m1/rd 6,2;
"Subjects' estimated log-likelihoods across look-up styles";
"Column 1 is Subj ID#, columns 2 and 3 estimated log-likelihood and type for";
"'early' look-up styles numbered 1 to 7,'late' look-up styles numbered 8 to 14";
"columns 4 to 13, identifies other types with equal estimated log-likelihood";
bloiswz;
print;

format /m1/rd 6,2;
"Number of games with zero compliance for the best estimated type ";
"Column 1 is Sub ID#, column 2 is number of games with zero       ";
"compliance of the best estimated type, column 3 indicator (1)    ";
"that parameter estimates are equal to {0 0 1}, (2, otherwise)    ";
btzcwz;
print;



output off;


